#include <stm32f30x_rcc.h>
#include <stm32f30x_misc.h>
#include <stm32f30x_gpio.h>
#include <stm32f30x_dac.h>
#include <stm32f30x_tim.h>
#include <beep.c> // zmieni np. na kukulka.c
#include <tick.c>
// definicje, ktre naley zmodyfikowa w zalenoci od potrzeb:

// deklaracja ta okrela zakres w jakim ma by przesuwana kukuka, obecna wartosc jest dostosowana do silnika ze
// stacji dyskietek, w przypadku silnika ze stacji CD-ROM, bdzie prawdopodobnie wiksza
#define zakres_wysuniecia 42

// deklaracja okresla liczb prbek z ktrych zoony jest plik przechowujcy dwik
// kukuki (ilosc elementw tablicy beep[] w pliku beep.c), w przypadku zmiany pliku dwikowego naley odpowiednio zmieni t liczb
//(np. dla pliku kukulka.c poda 25629
#define dlugosc_kuk 7808

// jw. ale dotyczy dwiku tykania
#define dlugosc_tick 1918

// uwaga! w przypadku zmiany plikw dwikowych naley take dobra odpowiedni czstotliwo prbkowania - funkcj konfigurujce
// timery: TIM3_Configuration(dwik kukuki), TIM17_Configuration(dwik tykania), oraz zmieni nazw odczytywanej tablicy w funkcji obsugi przerwania
// odpowiedni TIM3_IRQHandler() i  TIM17_IRQHandler()


volatile uint16_t n=0, i=0, krok,j=0;
volatile unsigned char kolejnosc=0, minuty=0,dz_minut=0,godziny=0,dz_godzin=0,pomocnicza=0,pelna_godz=0, beepniecie=0,liczba_beep=0,uruchom_sygnal=0,wsun=0;

const unsigned int cyfra[11]={0b0000001000000000,0b0000000000000001,0b0000000000000010,0b0000000000000100,0b0000000000001000,0b0000000000010000,
		0b0000000000100000,0b0000000001000000,0b0000000010000000,0b0000000100000000};
const unsigned int anoda[5]={0b0010000000000000,0b0001000000000000,0b0000100000000000,0b0000010000000000,0b0000000000000000};

const unsigned int silnik[4]={0b0000000000001000,0b0000000000000001,0b0000000000000100,0b0000000000000010};

// oponienie wykorzystane przy obsudze przyciskw (ustawianie godziny)
void opoznienie(void)
{
	long x,z;

	for(x=0;x<100;x++)
	{for(z=0;z<100;z++);}
}

// oponienie wykorzystane przy sterowaniu silnika
void opoznienie2(void)
{
	long x,z;

	for(x=0;x<1000;x++)
	{for(z=0;z<100;z++);}
}

// oponienie wykorzystane przy obsudze przyciskw (wybr trybu dwikowego)
void opoznienie3(void)
{
	long x,z;

	for(x=0;x<5000;x++)
	{for(z=0;z<1500;z++);}
}

// funkcja odpowiedzialna za wyczenie tykania na czas wydawania dwiku przez kukuk i zapewniajca ruch silnika
void ruch(void)
{
TIM_ITConfig(TIM16,TIM_IT_Update,DISABLE);
TIM_Cmd(TIM16, DISABLE);
TIM_ITConfig(TIM17,TIM_IT_Update,DISABLE);
TIM_Cmd(TIM17, DISABLE);

for(krok=0;krok<zakres_wysuniecia;krok++)
			{
				GPIOA->ODR = (silnik[0]|((GPIOA->ODR)&(0b1111111111110000)));
				opoznienie2();
				GPIOA->ODR = (silnik[1]|((GPIOA->ODR)&(0b1111111111110000)));
				opoznienie2();
				GPIOA->ODR = (silnik[2]|((GPIOA->ODR)&(0b1111111111110000)));
				opoznienie2();
				GPIOA->ODR = (silnik[3]|((GPIOA->ODR)&(0b1111111111110000)));
				opoznienie2();
			}
GPIOA->ODR = (0b0|((GPIOA->ODR)&(0b1111111111110000)));
}

// ustawienie priorytetw przerwa

void NVIC_Configuration(void)
{
	NVIC_InitTypeDef NVIC_Config_Structure;

	NVIC_Config_Structure.NVIC_IRQChannel = TIM2_IRQn;
	NVIC_Config_Structure.NVIC_IRQChannelPreemptionPriority =0;
	NVIC_Config_Structure.NVIC_IRQChannelSubPriority = 0;
	NVIC_Config_Structure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_Config_Structure);

	NVIC_Config_Structure.NVIC_IRQChannel = TIM3_IRQn;
	NVIC_Config_Structure.NVIC_IRQChannelPreemptionPriority =1;
	NVIC_Config_Structure.NVIC_IRQChannelSubPriority = 1;
	NVIC_Config_Structure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_Config_Structure);

	NVIC_Config_Structure.NVIC_IRQChannel = TIM4_IRQn;
	NVIC_Config_Structure.NVIC_IRQChannelPreemptionPriority =2;
	NVIC_Config_Structure.NVIC_IRQChannelSubPriority = 1;
	NVIC_Config_Structure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_Config_Structure);

	NVIC_Config_Structure.NVIC_IRQChannel = TIM1_UP_TIM16_IRQn;
	NVIC_Config_Structure.NVIC_IRQChannelPreemptionPriority =4;
	NVIC_Config_Structure.NVIC_IRQChannelSubPriority =1;
	NVIC_Config_Structure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_Config_Structure);

	NVIC_Config_Structure.NVIC_IRQChannel = TIM1_TRG_COM_TIM17_IRQn;
	NVIC_Config_Structure.NVIC_IRQChannelPreemptionPriority =3;
	NVIC_Config_Structure.NVIC_IRQChannelSubPriority = 1;
	NVIC_Config_Structure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_Config_Structure);

}


// konfiguracja portw WE/WY
void GPIO_Configuration(void)
{


	GPIO_InitTypeDef GPIO_InitStructure;

	// konfiguracja portu do obsugi anod i katod
  	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOB, ENABLE);

  	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 |GPIO_Pin_3 | GPIO_Pin_4 |GPIO_Pin_5 | GPIO_Pin_6 |GPIO_Pin_7 | GPIO_Pin_8 |GPIO_Pin_9 | GPIO_Pin_10 |GPIO_Pin_11 | GPIO_Pin_12 |GPIO_Pin_13 | GPIO_Pin_14 |GPIO_Pin_15 ;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_Level_1;
  	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL ;
  	GPIO_Init(GPIOB, &GPIO_InitStructure);

  	// konfiguracja portu do obsugi przyciskw
  	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);

  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4 |GPIO_Pin_5;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_Level_1;
  	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP ;
  	GPIO_Init(GPIOC, &GPIO_InitStructure);

  	//konfiguracja portu do sterowania silnikiem
  	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);

  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 |GPIO_Pin_1|GPIO_Pin_2 |GPIO_Pin_3;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_Level_1;
  	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL ;
  	GPIO_Init(GPIOA, &GPIO_InitStructure);

  	//konfiguracja DAC
  	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);
  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AN;
  	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  	GPIO_Init(GPIOA, &GPIO_InitStructure);

}


// fukcja konfigurujca przetwornik cyfrowo-analogowy

void DAC_Configuration(void)
{
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_DAC, ENABLE);

	DAC_InitTypeDef DAC_InitStructure;
	DAC_StructInit(&DAC_InitStructure);
	DAC_Cmd(DAC_Channel_1, ENABLE);
	DAC_SoftwareTriggerCmd(DAC_Channel_1, ENABLE);
	DAC_Init(DAC_Channel_1,&DAC_InitStructure);

}


// konfiguracja timera do odmierzania czasu
void TIM2_Configuration(void)
{

  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2,ENABLE);

  TIM_TimeBaseInitTypeDef TIM_TimeBaseStructure;

  TIM_TimeBaseStructInit(&TIM_TimeBaseStructure);
  TIM_TimeBaseStructure.TIM_Period =  36000-1;
  TIM_TimeBaseStructure.TIM_Prescaler = 60000-1;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
  TIM_TimeBaseInit(TIM2, &TIM_TimeBaseStructure);
  TIM_ITConfig(TIM2,TIM_IT_Update,ENABLE);

  TIM_Cmd(TIM2, ENABLE);
}

// konfiguracja timera do generacji czstotliwoci prbkowania przy odtwarzaniu pliku beep.c (dwik "kukuki"),
// przy zmianie pliku na inny naley dobra odpowiedni czstotliwosc prbkowania modyfikujc wartosci TIM_Period i TIM_Prescaler
// jeeli zastosujemy plik kukulka.c ,to ustawi: TIM_Period =39,  TIM_Prescaler=150
void TIM3_Configuration(void)
{
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE);

  TIM_TimeBaseInitTypeDef TIM_TimeBaseStructure;

  TIM_TimeBaseStructInit(&TIM_TimeBaseStructure);
  TIM_TimeBaseStructure.TIM_Period = 140-1;
  TIM_TimeBaseStructure.TIM_Prescaler = 100-1;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
  TIM_TimeBaseInit(TIM3, &TIM_TimeBaseStructure);
  TIM_ITConfig(TIM3,TIM_IT_Update,ENABLE);

  TIM_Cmd(TIM3, ENABLE);

}

// konfiguracja timera do multipleksowania wywietlaczy
void TIM4_Configuration(void)
{
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM4, ENABLE);

  TIM_TimeBaseInitTypeDef TIM_TimeBaseStructure;

  TIM_TimeBaseStructInit(&TIM_TimeBaseStructure);
  TIM_TimeBaseStructure.TIM_Period = 1000-1;
  TIM_TimeBaseStructure.TIM_Prescaler = 100-1;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
  TIM_TimeBaseInit(TIM4, &TIM_TimeBaseStructure);
  TIM_ITConfig(TIM4,TIM_IT_Update,ENABLE);

  TIM_Cmd(TIM4, ENABLE);

}

// konfiguracja timera, decydujcego z jak czstotliwoci zegar bdzie tyka - domyslnie co 2s

void TIM16_Configuration(void)
{
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_TIM16, ENABLE);

  TIM_TimeBaseInitTypeDef TIM_TimeBaseStructure;

  TIM_TimeBaseStructInit(&TIM_TimeBaseStructure);
  TIM_TimeBaseStructure.TIM_Period = 14400-1;
  TIM_TimeBaseStructure.TIM_Prescaler = 10000-1;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
  TIM_TimeBaseInit(TIM16, &TIM_TimeBaseStructure);
  TIM_ITConfig(TIM16,TIM_IT_Update,ENABLE);

  TIM_Cmd(TIM16, ENABLE);

}
// konfiguracja timera do generacji czstotliwoci prbkowania przy odtwarzaniu pliku tick.c (dwik "tykania"),
// przy zmianie pliku na inny naley dobra odpowiedni czstotliwosc prbkowania modyfikujc wartosci TIM_Period i TIM_Prescaler


void TIM17_Configuration(void)
{
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_TIM17, ENABLE);

  TIM_TimeBaseInitTypeDef TIM_TimeBaseStructure;

  TIM_TimeBaseStructInit(&TIM_TimeBaseStructure);
  TIM_TimeBaseStructure.TIM_Period = 16-1;
  TIM_TimeBaseStructure.TIM_Prescaler = 202-1;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
  TIM_TimeBaseInit(TIM17, &TIM_TimeBaseStructure);
  TIM_ITConfig(TIM17,TIM_IT_Update,ENABLE);

  TIM_Cmd(TIM17, ENABLE);

}

// obsuga przerwania od timera 2 - odmierzanie czasu

void TIM2_IRQHandler(void)
{
	if (TIM_GetITStatus(TIM2, TIM_IT_Update) != RESET)
	    {
	        TIM_ClearITPendingBit(TIM2, TIM_IT_Update);
	        pomocnicza++;
	        if(pomocnicza==2)
	        {
	        	pomocnicza=0;
	        	minuty++;
	        	if(minuty==10)
	        	{
	        		minuty = 0;
	        		dz_minut++;
	        		if(dz_minut==6)
	        		{
	        			dz_minut=0;
	        			godziny++;
	        			if(godziny==10)
	        			{
	        				godziny = 0;
	        				dz_godzin++;
	        			}
	        			if(dz_godzin==2 && godziny == 4)
	        			{
	        				godziny=0;
	        				dz_godzin=0;
	        			}
	        		}
	        	}
	       }

	    }
}

// obsuga przerwania od timera 3 - odtwarzanie pliku beep.c (kukuka), jeeli zmienimy odtwarzany plik, to zmieni odpowiednio
// nazw zmiennej z "beep[i]" np jeeli korzystamy z pliku kukulka.c, to wpisa: "kukulka[i]"
void TIM3_IRQHandler(void)
{
	if (TIM_GetITStatus(TIM3, TIM_IT_Update) != RESET)
	{
		TIM_ClearITPendingBit(TIM3, TIM_IT_Update);

		i++;
		if(i==dlugosc_kuk)
			{
			i=0;
			beepniecie++;
			}
		DAC_SetChannel1Data(DAC_Align_12b_R, 4095-beep[i]); //
		if(beepniecie==liczba_beep)
		{
		  beepniecie=0;
		  wsun =1;
		  TIM_ITConfig(TIM3,TIM_IT_Update,DISABLE);
		  TIM_Cmd(TIM3, DISABLE);
		  DAC_Cmd(DAC_Channel_1, DISABLE);

		 }

	}
}

// obsuga przerwania od timera 4 - multipleksowanie
void TIM4_IRQHandler(void)
{
	if (TIM_GetITStatus(TIM4, TIM_IT_Update) != RESET)
	{
		TIM_ClearITPendingBit(TIM4, TIM_IT_Update);
		kolejnosc++;
		if (kolejnosc==4)
			kolejnosc=0;

		if((kolejnosc==0)&&(dz_godzin!=0))
		{
			GPIOB->ODR = (cyfra[dz_godzin]|((GPIOB->ODR)&(0b1111110000000000)));
			GPIOB->ODR = (anoda[0]|((GPIOB->ODR)&(0b0000001111111111)));
		}

		if(kolejnosc==1)
		{
			GPIOB->ODR = (cyfra[godziny]|((GPIOB->ODR)&(0b1111110000000000)));
			GPIOB->ODR = (anoda[1]|((GPIOB->ODR)&(0b0000001111111111)));
		}

		if(kolejnosc==2)
		{
			GPIOB->ODR = (cyfra[dz_minut]|((GPIOB->ODR)&(0b1111110000000000)));
			GPIOB->ODR = (anoda[2]|((GPIOB->ODR)&(0b0000001111111111)));
		}

		if(kolejnosc==3)
		{
			GPIOB->ODR = (cyfra[minuty]|((GPIOB->ODR)&(0b1111110000000000)));
			GPIOB->ODR = (anoda[3]|((GPIOB->ODR)&(0b0000001111111111)));
		}


	}
}

// obsuga przerwania od timera 16 - zezwolenie na odtwarzanie pliku tick.c, czyli tyknicie
void TIM1_UP_TIM16_IRQHandler(void)
{
	if (TIM_GetITStatus(TIM16, TIM_IT_Update) != RESET)
	{
		TIM_ClearITPendingBit(TIM16, TIM_IT_Update);
		DAC_Configuration();
		TIM17_Configuration();
	}
}

// obsuga przerwania od timera 17 - odtwarzanie pliku tick.c (tykanie)
void TIM1_TRG_COM_TIM17_IRQHandler(void)
{
	if (TIM_GetITStatus(TIM17, TIM_IT_Update) != RESET)
	{
		TIM_ClearITPendingBit(TIM17, TIM_IT_Update);
		DAC_SetChannel1Data(DAC_Align_12b_R, 4095-tick[j]);
		j++;
		if(j==dlugosc_tick)
		{
		  j=0;
		  TIM_ITConfig(TIM17,TIM_IT_Update,DISABLE);
		  TIM_Cmd(TIM17, DISABLE);
		  DAC_Cmd(DAC_Channel_1, DISABLE);

		}

	}
}



int main(void)
{

uint8_t przycisk=0,przycisk2=0;
int8_t dzwiek=-1;


SystemInit(); // konfiguracja taktowania SysClk = 72MHz

// wstpna konfiguracja peryferiw - domyslnie wczone s wszystkie dwiki (tykanie + kukulka)
GPIO_Configuration();
NVIC_Configuration();
DAC_Configuration();
TIM2_Configuration();
TIM4_Configuration();
TIM16_Configuration();


while(1)
{
	if(GPIO_ReadInputDataBit(GPIOC,  GPIO_Pin_5) == Bit_RESET)
	przycisk2=1;


	if(GPIO_ReadInputDataBit(GPIOC,  GPIO_Pin_4) == Bit_RESET)
	przycisk=1;
// obsuga przyciskw(wybr trybu)
// zmiana trybu dwikowego dokonuje si przez jednoczesne nacinicie obydwu przyciskw:
// a) tryb domyslny (po zaczeniu zasilania) - dwiki kukuki i tykania wczone (dzwiek == -1 || dwik == 3)
// b) tryb cichy (wszystkie dwieki i wysuwanie kukuki wyczone)  (dzwiek == 0)
// c) tryb tykania - tylko dwik tykania, wysuwanie kukuki i kukanie wyczone  (dzwiek == 1)
// d) tryb kukuki - tylko syganlizacja penych godzin przez kukuk - tykanie zegara wyczone  (dzwiek == 2)

	if(GPIO_ReadInputDataBit(GPIOC,  GPIO_Pin_4) == Bit_RESET  && GPIO_ReadInputDataBit(GPIOC,  GPIO_Pin_5) == Bit_RESET )
	{
		przycisk = 0;
		przycisk2 = 0;
		dzwiek++;

			if(dzwiek>3)
			dzwiek=0;

			switch(dzwiek)
			{
			case 0:

				TIM_ITConfig(TIM16,TIM_IT_Update,DISABLE);
				TIM_Cmd(TIM16, DISABLE);
				TIM_ITConfig(TIM17,TIM_IT_Update,DISABLE);
				TIM_Cmd(TIM17, DISABLE);
				DAC_Cmd(DAC_Channel_1, DISABLE);

				break;

			case 1:
				TIM16_Configuration();
				break;

			case 2:
				TIM_ITConfig(TIM16,TIM_IT_Update,DISABLE);
				TIM_Cmd(TIM16, DISABLE);
				TIM_ITConfig(TIM17,TIM_IT_Update,DISABLE);
				TIM_Cmd(TIM17, DISABLE);
				DAC_Cmd(DAC_Channel_1, DISABLE);
				break;

			case 3:
				TIM16_Configuration();
				break;
			}

			opoznienie3();

	}

	// obsuga przyciskw - nacisnicie jednego przycisku zwiksza minuty, drugiego godziny
	else
	{

		if(GPIO_ReadInputDataBit(GPIOC,  GPIO_Pin_4) == Bit_SET && przycisk ==1)
		{
			przycisk =0;
			minuty++;
				if(minuty==10)
				{
					minuty=0;
					dz_minut++;
						if(dz_minut==6)
							dz_minut=0;
				}

		}


		if(GPIO_ReadInputDataBit(GPIOC,  GPIO_Pin_5) == Bit_SET && przycisk2 ==1)
		{
			przycisk2 =0;
			godziny++;
					if(godziny==10)
					{
						godziny=0;
						dz_godzin++;
					}

					if(dz_godzin==2 && godziny==4)
					{
						godziny=0;
						dz_godzin=0;
					}

		}

	}

	opoznienie();

	if(minuty!=0 && dz_minut!=0)
		uruchom_sygnal=1;

// obsuga wysuwania kukuki - domyslnie wychodzi ona o penych godzinach od 8 - 22. W razie potrzeby mona zmodyfikowa
	if(minuty==0 && dz_minut==0 && uruchom_sygnal==1 && (dzwiek==2 || dzwiek == 3 || dzwiek == -1))
	{
		uruchom_sygnal = 0;

		if(dz_godzin==1 && godziny == 1)
				{
			 	 	ruch();
					liczba_beep = 11;
					DAC_Configuration();
					TIM3_Configuration();
				}

		if(dz_godzin==1 && godziny == 3)
				{
			 	 	ruch();
					liczba_beep = 1;
					DAC_Configuration();
					TIM3_Configuration();
				}

		if(dz_godzin==1 && godziny == 4)
				{
					ruch();
					liczba_beep = 2;
					DAC_Configuration();
					TIM3_Configuration();
				}

		if(dz_godzin==1 && godziny == 5)
				{
					ruch();
					liczba_beep = 3;
					DAC_Configuration();
					TIM3_Configuration();
				}
		if(dz_godzin==1 && godziny == 6)
				{
					ruch();
					liczba_beep = 4;
					DAC_Configuration();
					TIM3_Configuration();
				}

		if(dz_godzin==1 && godziny == 7)
				{
			 	 	ruch();
					liczba_beep = 5;
					DAC_Configuration();
					TIM3_Configuration();
				}

		if(dz_godzin==1 && godziny == 8)
				{
					ruch();
					liczba_beep = 6;
					DAC_Configuration();
					TIM3_Configuration();
				}
		if(dz_godzin==1 && godziny == 9)
				{
					ruch();
					liczba_beep = 7;
					DAC_Configuration();
					TIM3_Configuration();
				}



		if((dz_godzin==0 && godziny == 8)||(dz_godzin==2 && godziny == 0))
				{
					ruch();
					liczba_beep = 8;
					DAC_Configuration();
					TIM3_Configuration();
				}

		if((dz_godzin==0 && godziny == 9)||(dz_godzin==2 && godziny == 1))
				{
					ruch();
					liczba_beep = 9;
					DAC_Configuration();
					TIM3_Configuration();
				}

		if((dz_godzin==1 && godziny == 0)||(dz_godzin==2 && godziny == 2))
				{
					ruch();
					liczba_beep = 10;
					DAC_Configuration();
					TIM3_Configuration();
				}


		if(dz_godzin==1 && godziny == 2)
				{
					ruch();
					liczba_beep = 12;
					DAC_Configuration();
					TIM3_Configuration();
				}


	}

	// powrt kukuki po odspiewaniu penej godziny
	if(wsun==1)
	{
		wsun=0;
		for(krok=0;krok<zakres_wysuniecia;krok++)
					{
						GPIOA->ODR = (silnik[3]|((GPIOA->ODR)&(0b1111111111110000)));
						opoznienie2();
						GPIOA->ODR = (silnik[2]|((GPIOA->ODR)&(0b1111111111110000)));
						opoznienie2();
						GPIOA->ODR = (silnik[1]|((GPIOA->ODR)&(0b1111111111110000)));
						opoznienie2();
						GPIOA->ODR = (silnik[0]|((GPIOA->ODR)&(0b1111111111110000)));
						opoznienie2();
					}
		GPIOA->ODR = (0b0|((GPIOA->ODR)&(0b1111111111110000)));
		if(dzwiek==3 || dzwiek ==1 || dzwiek ==-1)
		TIM_ITConfig(TIM16,TIM_IT_Update,ENABLE);
		TIM_Cmd(TIM16, ENABLE);
	}


}



while(1);
}
